package com.huiju.estateagents.eContract.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.huiju.estateagents.eContract.service.ITaCompanyService;
import com.huiju.estateagents.eContract.entity.TaCompany;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * 企业认证表  前端控制器
 * </p>
 *
 * @author fxf
 * @since 2020-03-26
 */
@RestController
@RequestMapping("/api")
public class TaCompanyController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCompanyController.class);

    @Autowired
    public ITaCompanyService iTaCompanyService;


    /**
     * 条件查询企业列表
     *
     * @param pageNum
     * @param pageSize
     * @param companyName
     * @param companyNumber
     * @param certifiedStatus
     * @return
     */
    @RequestMapping(value = "/channel/contract/lisCompany", method = RequestMethod.GET)
    public ResponseBean lisCompany(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                   @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                   String companyName, String companyNumber, String certifiedStatus) {
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaCompany> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaCompany> queryWrapper = new QueryWrapper<>();
            queryWrapper.like(StringUtils.isNotBlank(companyName), "company_name", companyName);
            queryWrapper.like(StringUtils.isNotBlank(companyNumber), "company_number", companyNumber);
            queryWrapper.eq(StringUtils.isNotBlank(certifiedStatus), "certified_status", certifiedStatus);
            queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
            queryWrapper.orderByDesc("create_date");

            IPage<TaCompany> result = iTaCompanyService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taCompanyList -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     *
     * @param taCompany 实体对象
     * @return
     */
    @RequestMapping(value = "/taCompany", method = RequestMethod.POST)
    public ResponseBean taCompanyAdd(@RequestBody TaCompany taCompany) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCompanyService.save(taCompany)) {
                responseBean.addSuccess(taCompany);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taCompanyAdd -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     */
    @ResponseBody
    @RequestMapping(value = "/taCompany/{id}", method = RequestMethod.DELETE)
    public ResponseBean taCompanyDelete(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCompanyService.removeById(id)) {
                responseBean.addSuccess("success");
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taCompanyDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     *
     * @param id        实体ID
     * @param taCompany 实体对象
     * @return
     */
    @RequestMapping(value = "/taCompany/{id}", method = RequestMethod.PUT)
    public ResponseBean taCompanyUpdate(@PathVariable Integer id,
                                        @RequestBody TaCompany taCompany) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaCompanyService.updateById(taCompany)) {
                responseBean.addSuccess(taCompany);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taCompanyUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     *
     * @param id 实体ID
     */
    @RequestMapping(value = "/taCompany/{id}", method = RequestMethod.GET)
    public ResponseBean taCompanyGet(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaCompanyService.getById(id));
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taCompanyDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

}
